@@ -347,16 +347,20 @@ class ExbetAPI:
 
         :param str market_id: Market id (1.24.xxxx)
         """
-        return self._post("lookup/selections", dict(market_id=market_id),).get(
-            "selections"
-        )
+        return self._post(
+            "lookup/selections",
+            dict(market_id=market_id),
+        ).get("selections")
 
     def lookup_market(self, market_id: str) -> dict:
         """Provides information about a market
 
         :param str market_id: Market  id (1.24.xxxx)
         """
-        return self._post("lookup/market", dict(market_id=market_id),)
+        return self._post(
+            "lookup/market",
+            dict(market_id=market_id),
+        )
 
     def lookup_markets(self, event_id: str) -> list:
         """
